=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2011-02-07 17:20:59 +0000
+++ drizzled/error.cc	2011-02-15 02:11:09 +0000
@@ -79,6 +79,41 @@
 
 error_handler_func error_handler_hook= NULL;
 
+namespace error {
+
+void access(drizzled::identifier::User::const_reference user)
+{
+  std::string user_string;
+  user.getSQLPath(user_string);
+
+  my_error(ER_ACCESS_DENIED_ERROR, MYF(0), user_string.c_str(),
+           user.hasPassword() ? ER(ER_YES) : ER(ER_NO));
+} 
+
+void access(drizzled::identifier::User::const_reference user, drizzled::identifier::Schema::const_reference schema)
+{
+  std::string user_string;
+  user.getSQLPath(user_string);
+
+  std::string schema_string;
+  schema.getSQLPath(schema_string);
+
+  my_error(ER_DBACCESS_DENIED_ERROR, MYF(0), user_string.c_str(), schema_string.c_str());
+} 
+
+void access(drizzled::identifier::User::const_reference user, drizzled::identifier::Table::const_reference table)
+{
+  std::string user_string;
+  user.getSQLPath(user_string);
+
+  std::string table_string;
+  table.getSQLPath(table_string);
+
+  my_error(ER_TABLEACCESS_DENIED_ERROR, MYF(0), user_string.c_str(), table_string.c_str());
+} 
+
+} // namespace error
+
 /*
   WARNING!
   my_error family functions have to be used according following rules:
@@ -246,8 +281,12 @@
   ADD_ERROR_MESSAGE(ER_OUT_OF_RESOURCES, N_("Out of memory; check if drizzled or some other process uses all available memory; if not, you may have to use 'ulimit' to allow drizzled to use more memory or you can add more swap space"));
   ADD_ERROR_MESSAGE(ER_BAD_HOST_ERROR, N_("Can't get hostname for your address"));
   ADD_ERROR_MESSAGE(ER_HANDSHAKE_ERROR, N_("Bad handshake"));
-  ADD_ERROR_MESSAGE(ER_DBACCESS_DENIED_ERROR, N_("Access denied for user '%-.48s'@'%-.64s' to schema '%-.192s'"));
-  ADD_ERROR_MESSAGE(ER_ACCESS_DENIED_ERROR, N_("Access denied for user '%-.48s'@'%-.64s' (using password: %s)"));
+
+  // Access error messages
+  ADD_ERROR_MESSAGE(ER_DBACCESS_DENIED_ERROR, N_("Access denied for user '%s' to schema '%s'"));
+  ADD_ERROR_MESSAGE(ER_TABLEACCESS_DENIED_ERROR, N_("Access denied for user '%s' to table '%s'"));
+  ADD_ERROR_MESSAGE(ER_ACCESS_DENIED_ERROR, N_("Access denied for user '%s' (using password: %s)"));
+
   ADD_ERROR_MESSAGE(ER_NO_DB_ERROR, N_("No schema selected"));
   ADD_ERROR_MESSAGE(ER_UNKNOWN_COM_ERROR, N_("Unknown command"));
   ADD_ERROR_MESSAGE(ER_BAD_NULL_ERROR, N_("Column '%-.192s' cannot be null"));

=== modified file 'drizzled/error.h'
--- drizzled/error.h	2011-01-26 19:15:55 +0000
+++ drizzled/error.h	2011-02-15 02:11:09 +0000
@@ -82,6 +82,15 @@
                        const std::string& message);
 #define DRIZZLE_ADD_ERROR_MESSAGE(code, msg) add_error_message(code, STRINGIFY_ARG(code), msg)
 
+namespace error {
+
+void access(drizzled::identifier::User::const_reference user);
+void access(drizzled::identifier::User::const_reference user, drizzled::identifier::Schema::const_reference schema);
+void access(drizzled::identifier::User::const_reference user, drizzled::identifier::Table::const_reference table);
+
+} // namespace error
+
+
 DRIZZLED_API void my_error(const std::string &ref, error_t nr, myf MyFlags= MYF(0));
 DRIZZLED_API void my_error(error_t nr, drizzled::Identifier::const_reference ref, myf MyFlags= MYF(0));
 DRIZZLED_API void my_error(error_t nr);

=== modified file 'drizzled/error_t.h'
--- drizzled/error_t.h	2011-02-07 17:20:59 +0000
+++ drizzled/error_t.h	2011-02-15 02:11:09 +0000
@@ -255,14 +255,14 @@
   ER_CANT_CREATE_THREAD,
   ER_WRONG_VALUE_COUNT_ON_ROW,
   ER_CANT_REOPEN_TABLE,
-  ER_UNUSED1138,
-  ER_UNUSED1139,
+  ER_INVALID_USE_OF_NULL,
+  ER_REGEXP_ERROR,
   ER_MIX_OF_GROUP_FUNC_AND_FIELDS,
-  ER_UNUSED1141,
-  ER_UNUSED1142,
-  ER_UNUSED1143,
-  ER_UNUSED1144,
-  ER_UNUSED1145,
+  ER_NONEXISTING_GRANT,
+  ER_TABLEACCESS_DENIED_ERROR,
+  ER_COLUMNACCESS_DENIED_ERROR,
+  ER_ILLEGAL_GRANT_FOR_TABLE,
+  ER_GRANT_WRONG_HOST_OR_USER,
   ER_TABLE_UNKNOWN,
   ER_UNUSED1147,
   ER_UNUSED1148,

=== modified file 'drizzled/generator/all_tables.h'
--- drizzled/generator/all_tables.h	2011-01-17 04:15:23 +0000
+++ drizzled/generator/all_tables.h	2011-02-13 05:14:35 +0000
@@ -29,7 +29,6 @@
 class AllTables
 {
   Session &session;
-  message::table::shared_ptr table;
 
   identifier::Table::vector table_names;
   identifier::Table::vector::const_iterator table_iterator;
@@ -50,10 +49,11 @@
     do {
       while (table_iterator != table_names.end())
       {
-        bool is_table_parsed= plugin::StorageEngine::getTableDefinition(session, *table_iterator, table);
+        message::table::shared_ptr table;
+        table= plugin::StorageEngine::getTableMessage(session, *table_iterator);
         table_iterator++;
 
-        if (is_table_parsed)
+        if (table)
           return table;
       }
     } while ((schema_ptr= schema_generator) && table_setup());

=== modified file 'drizzled/generator/schema.cc'
--- drizzled/generator/schema.cc	2011-02-12 10:48:53 +0000
+++ drizzled/generator/schema.cc	2011-02-15 21:01:34 +0000
@@ -46,16 +46,16 @@
   {
     identifier::Schema schema_identifier(*schema_iterator);
 
-    if (not plugin::Authorization::isAuthorized(session.user(), schema_identifier, false))
+    if (not plugin::Authorization::isAuthorized(*session.user(), schema_identifier, false))
     {
       schema_iterator++;
       continue;
     }
 
-    bool is_schema_parsed= plugin::StorageEngine::getSchemaDefinition(schema_identifier, schema);
+    schema= plugin::StorageEngine::getSchemaDefinition(schema_identifier);
     schema_iterator++;
 
-    if (is_schema_parsed)
+    if (schema)
       return schema;
   }
 
@@ -69,7 +69,7 @@
     const drizzled::identifier::Schema *_ptr= &(*schema_iterator);
     schema_iterator++;
 
-    if (not plugin::Authorization::isAuthorized(session.user(), *_ptr, false))
+    if (not plugin::Authorization::isAuthorized(*session.user(), *_ptr, false))
       continue;
 
     return _ptr;

=== modified file 'drizzled/generator/table.h'
--- drizzled/generator/table.h	2011-02-12 08:30:55 +0000
+++ drizzled/generator/table.h	2011-02-16 01:50:09 +0000
@@ -32,7 +32,6 @@
 class Table
 {
   Session &session;
-  message::table::shared_ptr table;
 
   identifier::Table::vector table_names;
   identifier::Table::vector::const_iterator table_iterator;
@@ -45,11 +44,11 @@
   {
     while (table_iterator != table_names.end())
     {
-      table->Clear();
-      bool is_table_parsed= plugin::StorageEngine::getTableDefinition(session, *table_iterator, table);
+      message::table::shared_ptr table;
+      table= plugin::StorageEngine::getTableMessage(session, *table_iterator);
       table_iterator++;
 
-      if (is_table_parsed)
+      if (table)
         return table;
     }
 

=== modified file 'drizzled/identifier/user.cc'
--- drizzled/identifier/user.cc	2011-01-04 18:14:33 +0000
+++ drizzled/identifier/user.cc	2011-02-16 00:52:49 +0000
@@ -36,12 +36,19 @@
 {
   if (_user.empty())
   {
-    arg.append("no user");
+    arg+= "<no user>";
   }
   else
   {
-    arg.append(_user);
+    arg+= _user;
   }
+  // We should fix the below, to do so we need to match on localhost when we
+  // create the object.
+#if 0
+  arg+= "@";
+  arg+= _address;
+#endif
+
 }
 
 } /* namespace identifier */

=== modified file 'drizzled/identifier/user.h'
--- drizzled/identifier/user.h	2011-01-26 19:15:55 +0000
+++ drizzled/identifier/user.h	2011-02-15 02:11:09 +0000
@@ -47,18 +47,33 @@
 
   enum PasswordType
   {
+    NONE,
     PLAIN_TEXT,
     MYSQL_HASH
   };
 
   User():
-    password_type(PLAIN_TEXT),
+    password_type(NONE),
     _user(""),
     _address("")
   { }
 
   virtual void getSQLPath(std::string &arg) const;
 
+  bool hasPassword() const
+  {
+    switch (password_type)
+    {
+    case NONE:
+      return false;
+    case PLAIN_TEXT:
+    case MYSQL_HASH:
+      break;
+    }
+
+    return true;
+  }
+
   const std::string& address() const
   {
     return _address;

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2011-02-14 20:15:25 +0000
+++ drizzled/include.am	2011-02-15 21:01:34 +0000
@@ -71,7 +71,6 @@
 			      drizzled/cursor.h \
 			      drizzled/daemon.h \
 			      drizzled/data_home.h \
-			      drizzled/db.h \
 			      drizzled/debug.h \
 			      drizzled/definition/cache.h \
 			      drizzled/definitions.h \
@@ -383,6 +382,7 @@
 			      drizzled/refresh_version.h \
 			      drizzled/replication_services.h \
 			      drizzled/resource_context.h \
+			      drizzled/schema.h \
 			      drizzled/select_create.h \
 			      drizzled/select_dump.h \
 			      drizzled/select_dumpvar.h \
@@ -930,7 +930,7 @@
 				 drizzled/temporal_format.cc \
 				 drizzled/temporal_interval.cc
 drizzled_libtypelib_la_SOURCES = drizzled/typelib.cc
-drizzled_libserialutil_la_SOURCES = drizzled/db.cc drizzled/table_proto_write.cc
+drizzled_libserialutil_la_SOURCES = drizzled/schema.cc drizzled/table_proto_write.cc
 drizzled_libserialutil_la_CXXFLAGS= ${AM_CXXFLAGS} ${PROTOSKIP_WARNINGS}
 
 drizzled_libcached_directory_la_SOURCES=drizzled/cached_directory.cc

=== modified file 'drizzled/message.cc'
--- drizzled/message.cc	2011-02-03 01:52:43 +0000
+++ drizzled/message.cc	2011-02-14 02:47:12 +0000
@@ -22,7 +22,7 @@
 
 #include <drizzled/show.h>
 #include <drizzled/session.h>
-#include <drizzled/db.h>
+#include <drizzled/schema.h>
 #include <drizzled/plugin/event_observer.h>
 #include <drizzled/message.h>
 

=== modified file 'drizzled/parser.h'
--- drizzled/parser.h	2011-02-14 05:47:07 +0000
+++ drizzled/parser.h	2011-02-15 21:01:34 +0000
@@ -17,7 +17,6 @@
 #define DRIZZLED_PARSER_H
 
 #include <drizzled/charset.h>
-#include <drizzled/db.h>
 #include <drizzled/error.h>
 #include <drizzled/foreign_key.h>
 #include <drizzled/function/get_system_var.h>
@@ -110,7 +109,6 @@
 #include <drizzled/statement/truncate.h>
 #include <drizzled/statement/unlock_tables.h>
 #include <drizzled/statement/update.h>
-#include <drizzled/thr_lock.h>
 
 namespace drizzled {
 

=== modified file 'drizzled/plugin/authentication.cc'
--- drizzled/plugin/authentication.cc	2010-12-18 18:24:57 +0000
+++ drizzled/plugin/authentication.cc	2011-02-15 02:11:09 +0000
@@ -64,7 +64,7 @@
   }
 };
 
-bool plugin::Authentication::isAuthenticated(drizzled::identifier::User::const_shared_ptr sctx,
+bool plugin::Authentication::isAuthenticated(drizzled::identifier::User::const_reference sctx,
                                              const std::string &password)
 {
   /* If we never loaded any auth plugins, just return true */
@@ -74,7 +74,7 @@
   /* Use find_if instead of foreach so that we can collect return codes */
   std::vector<plugin::Authentication *>::iterator iter=
     std::find_if(all_authentication.begin(), all_authentication.end(),
-                 AuthenticateBy(*sctx, password));
+                 AuthenticateBy(sctx, password));
 
   /* We only require one plugin to return success in order to authenticate.
    * If iter is == end() here, that means that all of the plugins returned
@@ -82,10 +82,7 @@
    */
   if (iter == all_authentication.end())
   {
-    my_error(ER_ACCESS_DENIED_ERROR, MYF(0),
-             sctx->username().c_str(),
-             sctx->address().c_str(),
-             password.empty() ? ER(ER_NO) : ER(ER_YES));
+    error::access(sctx);
 
     return false;
   }

=== modified file 'drizzled/plugin/authentication.h'
--- drizzled/plugin/authentication.h	2011-01-26 19:15:55 +0000
+++ drizzled/plugin/authentication.h	2011-02-14 19:09:02 +0000
@@ -56,7 +56,7 @@
 
   static bool addPlugin(plugin::Authentication *auth);
   static void removePlugin(plugin::Authentication *auth);
-  static bool isAuthenticated(drizzled::identifier::User::const_shared_ptr sctx,
+  static bool isAuthenticated(drizzled::identifier::User::const_reference sctx,
                               const std::string &password);
 };
 

=== modified file 'drizzled/plugin/authorization.cc'
--- drizzled/plugin/authorization.cc	2011-01-17 04:15:23 +0000
+++ drizzled/plugin/authorization.cc	2011-02-15 02:11:09 +0000
@@ -78,11 +78,11 @@
 class RestrictTableFunctor :
   public std::unary_function<plugin::Authorization *, bool>
 {
-  const identifier::User &user_ctx;
-  identifier::Table &table;
+  identifier::User::const_reference user_ctx;
+  identifier::Table::const_reference table;
 public:
-  RestrictTableFunctor(const identifier::User &user_ctx_arg,
-                       identifier::Table &table_arg) :
+  RestrictTableFunctor(identifier::User::const_reference user_ctx_arg,
+                       identifier::Table::const_reference table_arg) :
     std::unary_function<plugin::Authorization *, bool>(),
     user_ctx(user_ctx_arg),
     table(table_arg)
@@ -116,9 +116,9 @@
 class PruneSchemaFunctor :
   public std::unary_function<identifier::Schema&, bool>
 {
-  drizzled::identifier::User::const_shared_ptr user_ctx;
+  drizzled::identifier::User::const_reference user_ctx;
 public:
-  PruneSchemaFunctor(drizzled::identifier::User::const_shared_ptr user_ctx_arg) :
+  PruneSchemaFunctor(drizzled::identifier::User::const_reference user_ctx_arg) :
     std::unary_function<identifier::Schema&, bool>(),
     user_ctx(user_ctx_arg)
   { }
@@ -131,7 +131,7 @@
 
 } /* namespace */
 
-bool plugin::Authorization::isAuthorized(identifier::User::const_shared_ptr user_ctx,
+bool plugin::Authorization::isAuthorized(identifier::User::const_reference user_ctx,
                                          identifier::Schema::const_reference schema_identifier,
                                          bool send_error)
 {
@@ -143,7 +143,7 @@
   std::vector<plugin::Authorization *>::const_iterator iter=
     std::find_if(authorization_plugins.begin(),
                  authorization_plugins.end(),
-                 RestrictDbFunctor(*user_ctx, schema_identifier));
+                 RestrictDbFunctor(user_ctx, schema_identifier));
 
 
   /*
@@ -155,21 +155,15 @@
   {
     if (send_error)
     {
-      std::string path;
-      schema_identifier.getSQLPath(path);
-
-      my_error(ER_DBACCESS_DENIED_ERROR, MYF(0),
-               user_ctx->username().c_str(),
-               user_ctx->address().c_str(),
-               path.c_str());
+      error::access(user_ctx, schema_identifier);
     }
     return false;
   }
   return true;
 }
 
-bool plugin::Authorization::isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
-                                         identifier::Table &table,
+bool plugin::Authorization::isAuthorized(drizzled::identifier::User::const_reference user_ctx,
+                                         identifier::Table::const_reference table_identifier,
                                          bool send_error)
 {
   /* If we never loaded any authorization plugins, just return true */
@@ -180,7 +174,7 @@
   std::vector<plugin::Authorization *>::const_iterator iter=
     std::find_if(authorization_plugins.begin(),
             authorization_plugins.end(),
-            RestrictTableFunctor(*user_ctx, table));
+            RestrictTableFunctor(user_ctx, table_identifier));
 
   /*
    * If iter is == end() here, that means that all of the plugins returned
@@ -191,35 +185,25 @@
   {
     if (send_error)
     {
-      std::string path;
-      table.getSQLPath(path);
-
-      my_error(ER_DBACCESS_DENIED_ERROR, MYF(0),
-               user_ctx->username().c_str(),
-               user_ctx->address().c_str(),
-               path.c_str());
+      error::access(user_ctx, table_identifier);
     }
     return false;
   }
   return true;
 }
 
-bool plugin::Authorization::isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
-                                         const Session *session,
-                                         bool send_error)
-{
-  return isAuthorized(*user_ctx, session, send_error);
-}
-
 bool plugin::Authorization::isAuthorized(drizzled::identifier::User::const_reference user_ctx,
-                                         const Session *session,
+                                         Session::const_reference session,
                                          bool send_error)
 {
-  drizzled::identifier::User::const_shared_ptr session_ctx= session->user();
-
   /* If we never loaded any authorization plugins, just return true */
   if (authorization_plugins.empty())
     return true;
+  
+  // To make sure we hold the user structure we need to have a shred_ptr so
+  // that we increase the count on the object.
+  drizzled::identifier::User::const_shared_ptr session_ctx= session.user();
+
 
   /* Use find_if instead of foreach so that we can collect return codes */
   std::vector<plugin::Authorization *>::const_iterator iter=
@@ -237,7 +221,7 @@
   {
     if (send_error)
     {
-      my_error(ER_KILL_DENIED_ERROR, MYF(0), session->thread_id);
+      my_error(ER_KILL_DENIED_ERROR, MYF(0), session.thread_id);
     }
     return false;
   }
@@ -245,7 +229,7 @@
   return true;
 }
 
-void plugin::Authorization::pruneSchemaNames(drizzled::identifier::User::const_shared_ptr user_ctx,
+void plugin::Authorization::pruneSchemaNames(drizzled::identifier::User::const_reference user_ctx,
                                              identifier::Schema::vector &set_of_schemas)
 {
   /* If we never loaded any authorization plugins, just return true */

=== modified file 'drizzled/plugin/authorization.h'
--- drizzled/plugin/authorization.h	2011-01-26 19:15:55 +0000
+++ drizzled/plugin/authorization.h	2011-02-15 02:11:09 +0000
@@ -68,8 +68,8 @@
    *
    * @returns true if the user cannot access the table
    */
-  virtual bool restrictTable(const drizzled::identifier::User &user_ctx,
-                             identifier::Table &table);
+  virtual bool restrictTable(drizzled::identifier::User::const_reference user_ctx,
+                             drizzled::identifier::Table::const_reference table);
 
   /**
    * Should we restrict the current user's access to see this process?
@@ -84,30 +84,25 @@
                                const drizzled::identifier::User &session_ctx);
 
   /** Server API method for checking schema authorization */
-  static bool isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
+  static bool isAuthorized(drizzled::identifier::User::const_reference user_ctx,
                            identifier::Schema::const_reference schema_identifier,
                            bool send_error= true);
 
   /** Server API method for checking table authorization */
-  static bool isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
-                           identifier::Table &table_identifier,
-                           bool send_error= true);
-
-  /** Server API method for checking process authorization */
-  static bool isAuthorized(drizzled::identifier::User::const_shared_ptr user_ctx,
-                           const Session *session,
-                           bool send_error= true);
-
-  /** Server API method for checking process authorization */
-  static bool isAuthorized(drizzled::identifier::User::const_reference user_ctx,
-                           const Session *session,
+  static bool isAuthorized(drizzled::identifier::User::const_reference user_ctx,
+                           drizzled::identifier::Table::const_reference table_identifier,
+                           bool send_error= true);
+
+  /** Server API method for checking process authorization */
+  static bool isAuthorized(drizzled::identifier::User::const_reference user_ctx,
+                           const Session &session,
                            bool send_error= true);
 
   /**
    * Server API helper method for applying authorization tests
    * to a set of schema names (for use in the context of getSchemaNames
    */
-  static void pruneSchemaNames(drizzled::identifier::User::const_shared_ptr user_ctx,
+  static void pruneSchemaNames(drizzled::identifier::User::const_reference user_ctx,
                                identifier::Schema::vector &set_of_schemas);
   
   /**
@@ -118,8 +113,8 @@
 
 };
 
-inline bool Authorization::restrictTable(const drizzled::identifier::User &user_ctx,
-                                         identifier::Table &table)
+inline bool Authorization::restrictTable(drizzled::identifier::User::const_reference user_ctx,
+                                         drizzled::identifier::Table::const_reference table)
 {
   return restrictSchema(user_ctx, table);
 }

=== modified file 'drizzled/plugin/schema_engine.cc'
--- drizzled/plugin/schema_engine.cc	2011-02-01 02:51:01 +0000
+++ drizzled/plugin/schema_engine.cc	2011-02-14 19:09:02 +0000
@@ -58,7 +58,7 @@
   std::for_each(StorageEngine::getSchemaEngines().begin(), StorageEngine::getSchemaEngines().end(),
            AddSchemaNames(schemas));
 
-  plugin::Authorization::pruneSchemaNames(session.user(), schemas);
+  plugin::Authorization::pruneSchemaNames(*session.user(), schemas);
 }
 
 class StorageEngineGetSchemaDefinition: public std::unary_function<StorageEngine *, bool>
@@ -76,48 +76,50 @@
 
   result_type operator() (argument_type engine)
   {
-    return engine->doGetSchemaDefinition(identifier, schema_proto);
+    schema_proto= engine->doGetSchemaDefinition(identifier);
+    return schema_proto;
   }
 };
 
 /*
   Return value is "if parsed"
 */
-bool StorageEngine::getSchemaDefinition(const drizzled::identifier::Table &identifier, message::schema::shared_ptr &proto)
+message::schema::shared_ptr StorageEngine::getSchemaDefinition(const drizzled::identifier::Table &identifier)
 {
-  return StorageEngine::getSchemaDefinition(identifier, proto);
+  return StorageEngine::getSchemaDefinition(identifier);
 }
 
-bool StorageEngine::getSchemaDefinition(const identifier::Schema &identifier, message::schema::shared_ptr &proto)
+message::schema::shared_ptr StorageEngine::getSchemaDefinition(const identifier::Schema &identifier)
 {
+  message::schema::shared_ptr proto;
+
   EngineVector::iterator iter=
     std::find_if(StorageEngine::getSchemaEngines().begin(), StorageEngine::getSchemaEngines().end(),
                  StorageEngineGetSchemaDefinition(identifier, proto));
 
   if (iter != StorageEngine::getSchemaEngines().end())
   {
-    return true;
+    return proto;
   }
 
-  return false;
+  return message::schema::shared_ptr();
 }
 
 bool StorageEngine::doesSchemaExist(const identifier::Schema &identifier)
 {
   message::schema::shared_ptr proto;
 
-  return StorageEngine::getSchemaDefinition(identifier, proto);
+  return StorageEngine::getSchemaDefinition(identifier);
 }
 
 
 const CHARSET_INFO *StorageEngine::getSchemaCollation(const identifier::Schema &identifier)
 {
   message::schema::shared_ptr schmema_proto;
-  bool found;
-
-  found= StorageEngine::getSchemaDefinition(identifier, schmema_proto);
-
-  if (found && schmema_proto->has_collation())
+
+  schmema_proto= StorageEngine::getSchemaDefinition(identifier);
+
+  if (schmema_proto && schmema_proto->has_collation())
   {
     const std::string buffer= schmema_proto->collation();
     const CHARSET_INFO* cs= get_charset_by_name(buffer.c_str());

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2011-02-13 01:25:00 +0000
+++ drizzled/plugin/storage_engine.cc	2011-02-15 21:01:34 +0000
@@ -49,7 +49,6 @@
 #include "drizzled/global_charset_info.h"
 #include "drizzled/charset.h"
 #include "drizzled/internal/my_sys.h"
-#include "drizzled/db.h"
 
 #include <drizzled/table_proto.h>
 #include <drizzled/plugin/event_observer.h>
@@ -362,55 +361,11 @@
   return false;
 }
 
-/**
-  Call this function in order to give the Cursor the possiblity
-  to ask engine if there are any new tables that should be written to disk
-  or any dropped tables that need to be removed from disk
-*/
-int StorageEngine::getTableDefinition(Session& session,
-                                      const identifier::Table &identifier,
-                                      message::table::shared_ptr &table_message,
-                                      bool include_temporary_tables)
-{
-  drizzled::error_t err= static_cast<drizzled::error_t>(ENOENT);
-
-  if (include_temporary_tables)
-  {
-    Table *table= session.find_temporary_table(identifier);
-    if (table)
-    {
-      table_message.reset(new message::Table(*table->getShare()->getTableMessage()));
-      return EEXIST;
-    }
-  }
-
-  drizzled::message::table::shared_ptr table_ptr;
-  if ((table_ptr= drizzled::message::Cache::singleton().find(identifier)))
-  {
-    table_message= table_ptr;
-  }
-
-  message::Table message;
-  EngineVector::iterator iter=
-    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
-                 StorageEngineGetTableDefinition(session, identifier, message, err));
-
-  if (iter == vector_of_engines.end())
-  {
-    return ENOENT;
-  }
-  table_message.reset(new message::Table(message));
-
- drizzled::message::Cache::singleton().insert(identifier, table_message);
-
-  return err;
-}
-
 message::table::shared_ptr StorageEngine::getTableMessage(Session& session,
                                                           identifier::Table::const_reference identifier,
-                                                          drizzled::error_t &error,
                                                           bool include_temporary_tables)
 {
+  drizzled::error_t error;
   error= static_cast<drizzled::error_t>(ENOENT);
 
   if (include_temporary_tables)
@@ -418,7 +373,6 @@
     Table *table= session.find_temporary_table(identifier);
     if (table)
     {
-      error= EE_OK;
       return message::table::shared_ptr(new message::Table(*table->getShare()->getTableMessage()));
     }
   }
@@ -436,7 +390,6 @@
 
   if (iter == vector_of_engines.end())
   {
-    error= static_cast<drizzled::error_t>(ENOENT);
     return message::table::shared_ptr();
   }
   message::table::shared_ptr table_message(new message::Table(message));

=== modified file 'drizzled/plugin/storage_engine.h'
--- drizzled/plugin/storage_engine.h	2011-02-13 10:42:38 +0000
+++ drizzled/plugin/storage_engine.h	2011-02-15 21:01:34 +0000
@@ -323,13 +323,8 @@
   static bool addPlugin(plugin::StorageEngine *engine);
   static void removePlugin(plugin::StorageEngine *engine);
 
-  static int getTableDefinition(Session& session,
-                                const drizzled::identifier::Table &identifier,
-                                message::table::shared_ptr &table_proto,
-                                bool include_temporary_tables= true);
   static message::table::shared_ptr getTableMessage(Session& session,
                                                     const drizzled::identifier::Table &identifier,
-                                                    drizzled::error_t &error,
                                                     bool include_temporary_tables= true);
   static bool doesTableExist(Session &session,
                              const drizzled::identifier::Table &identifier,
@@ -362,8 +357,8 @@
 
   // @note All schema methods defined here
   static void getIdentifiers(Session &session, identifier::Schema::vector &schemas);
-  static bool getSchemaDefinition(const drizzled::identifier::Table &identifier, message::schema::shared_ptr &proto);
-  static bool getSchemaDefinition(const drizzled::identifier::Schema &identifier, message::schema::shared_ptr &proto);
+  static message::schema::shared_ptr getSchemaDefinition(const drizzled::identifier::Table &identifier);
+  static message::schema::shared_ptr getSchemaDefinition(const drizzled::identifier::Schema &identifier);
   static bool doesSchemaExist(const drizzled::identifier::Schema &identifier);
   static const CHARSET_INFO *getSchemaCollation(const drizzled::identifier::Schema &identifier);
   static bool createSchema(const drizzled::message::Schema &schema_message);
@@ -375,9 +370,9 @@
   virtual void doGetSchemaIdentifiers(identifier::Schema::vector&)
   { }
 
-  virtual bool doGetSchemaDefinition(const drizzled::identifier::Schema&, drizzled::message::schema::shared_ptr&)
+  virtual drizzled::message::schema::shared_ptr doGetSchemaDefinition(const drizzled::identifier::Schema&)
   { 
-    return false; 
+    return drizzled::message::schema::shared_ptr(); 
   }
 
   virtual bool doCreateSchema(const drizzled::message::Schema&)

=== renamed file 'drizzled/db.cc' => 'drizzled/schema.cc'
--- drizzled/db.cc	2011-01-24 21:05:10 +0000
+++ drizzled/schema.cc	2011-02-14 19:09:02 +0000
@@ -25,28 +25,27 @@
 #include <string>
 #include <fstream>
 
-#include "drizzled/error.h"
+#include <drizzled/error.h>
 #include <drizzled/gettext.h>
 #include <drizzled/my_hash.h>
-#include "drizzled/internal/m_string.h"
+#include <drizzled/internal/m_string.h>
 #include <drizzled/session.h>
-#include <drizzled/db.h>
+#include <drizzled/schema.h>
 #include <drizzled/sql_base.h>
 #include <drizzled/lock.h>
 #include <drizzled/errmsg_print.h>
 #include <drizzled/transaction_services.h>
 #include <drizzled/message/schema.pb.h>
-#include "drizzled/sql_table.h"
-#include "drizzled/plugin/storage_engine.h"
-#include "drizzled/plugin/authorization.h"
-#include "drizzled/global_charset_info.h"
-#include "drizzled/pthread_globals.h"
-#include "drizzled/charset.h"
+#include <drizzled/sql_table.h>
+#include <drizzled/plugin/storage_engine.h>
+#include <drizzled/plugin/authorization.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/pthread_globals.h>
+#include <drizzled/charset.h>
+#include <drizzled/internal/my_sys.h>
 
 #include <boost/thread/mutex.hpp>
 
-#include "drizzled/internal/my_sys.h"
-
 #define MAX_DROP_TABLE_Q_LEN      1024
 
 using namespace std;
@@ -54,8 +53,11 @@
 namespace drizzled
 {
 
-static void change_db_impl(Session *session);
-static void change_db_impl(Session *session, identifier::Schema &schema_identifier);
+namespace schema
+{
+
+static void change_db_impl(Session &session);
+static void change_db_impl(Session &session, identifier::Schema &schema_identifier);
 
 /*
   Create a database
@@ -78,7 +80,7 @@
 
 */
 
-bool create_db(Session *session, const message::Schema &schema_message, const bool is_if_not_exists)
+bool create(Session &session, const message::Schema &schema_message, const bool is_if_not_exists)
 {
   TransactionServices &transaction_services= TransactionServices::singleton();
   bool error= false;
@@ -95,7 +97,7 @@
     has the global read lock and refuses the operation with
     ER_CANT_UPDATE_WITH_READLOCK if applicable.
   */
-  if (session->wait_if_global_read_lock(false, true))
+  if (session.wait_if_global_read_lock(false, true))
   {
     return false;
   }
@@ -105,7 +107,7 @@
 
   // @todo push this lock down into the engine
   {
-    boost::mutex::scoped_lock scopedLock(session->catalog().schemaLock());
+    boost::mutex::scoped_lock scopedLock(session.catalog().schemaLock());
 
     // Check to see if it exists already.  
     identifier::Schema schema_identifier(schema_message.name());
@@ -118,10 +120,10 @@
       }
       else
       {
-        push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
+        push_warning_printf(&session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                             ER_DB_CREATE_EXISTS, ER(ER_DB_CREATE_EXISTS),
                             schema_message.name().c_str());
-        session->my_ok();
+        session.my_ok();
       }
     }
     else if (not plugin::StorageEngine::createSchema(schema_message)) // Try to create it 
@@ -131,11 +133,11 @@
     }
     else // Created !
     {
-      transaction_services.createSchema(*session, schema_message);
-      session->my_ok(1);
+      transaction_services.createSchema(session, schema_message);
+      session.my_ok(1);
     }
   }
-  session->startWaitingGlobalReadLock();
+  session.startWaitingGlobalReadLock();
 
   return error;
 }
@@ -143,9 +145,9 @@
 
 /* db-name is already validated when we come here */
 
-bool alter_db(Session *session,
-              const message::Schema &schema_message,
-              const message::schema::shared_ptr &original_schema)
+bool alter(Session &session,
+           const message::Schema &schema_message,
+           const message::Schema &original_schema)
 {
   TransactionServices &transaction_services= TransactionServices::singleton();
 
@@ -161,12 +163,12 @@
     has the global read lock and refuses the operation with
     ER_CANT_UPDATE_WITH_READLOCK if applicable.
   */
-  if ((session->wait_if_global_read_lock(false, true)))
+  if ((session.wait_if_global_read_lock(false, true)))
     return false;
 
   bool success;
   {
-    boost::mutex::scoped_lock scopedLock(session->catalog().schemaLock());
+    boost::mutex::scoped_lock scopedLock(session.catalog().schemaLock());
 
     identifier::Schema schema_idenifier(schema_message.name());
     if (not plugin::StorageEngine::doesSchemaExist(schema_idenifier))
@@ -180,15 +182,15 @@
 
     if (success)
     {
-      transaction_services.alterSchema(*session, original_schema, schema_message);
-      session->my_ok(1);
+      transaction_services.alterSchema(session, original_schema, schema_message);
+      session.my_ok(1);
     }
     else
     {
       my_error(ER_ALTER_SCHEMA, schema_idenifier);
     }
   }
-  session->startWaitingGlobalReadLock();
+  session.startWaitingGlobalReadLock();
 
   return success;
 }
@@ -211,7 +213,7 @@
     ERROR Error
 */
 
-bool rm_db(Session *session, identifier::Schema &schema_identifier, const bool if_exists)
+bool drop(Session &session, identifier::Schema &schema_identifier, const bool if_exists)
 {
   bool error= false;
 
@@ -227,14 +229,14 @@
     has the global read lock and refuses the operation with
     ER_CANT_UPDATE_WITH_READLOCK if applicable.
   */
-  if (session->wait_if_global_read_lock(false, true))
+  if (session.wait_if_global_read_lock(false, true))
   {
     return true;
   }
 
   do
   {
-    boost::mutex::scoped_lock scopedLock(session->catalog().schemaLock());
+    boost::mutex::scoped_lock scopedLock(session.catalog().schemaLock());
 
     /* See if the schema exists */
     if (not plugin::StorageEngine::doesSchemaExist(schema_identifier))
@@ -244,7 +246,7 @@
         std::string path;
         schema_identifier.getSQLPath(path);
 
-        push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
+        push_warning_printf(&session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                             ER_DB_DROP_EXISTS, ER(ER_DB_DROP_EXISTS),
                             path.c_str());
       }
@@ -257,7 +259,7 @@
     }
     else
     {
-      error= plugin::StorageEngine::dropSchema(*session, schema_identifier);
+      error= plugin::StorageEngine::dropSchema(session, schema_identifier);
     }
 
   } while (0);
@@ -268,10 +270,10 @@
     SELECT DATABASE() in the future). For this we free() session->db and set
     it to 0.
   */
-  if (not error and schema_identifier.compare(*session->schema()))
+  if (not error and schema_identifier.compare(*session.schema()))
     change_db_impl(session);
 
-  session->startWaitingGlobalReadLock();
+  session.startWaitingGlobalReadLock();
 
   return error;
 }
@@ -338,16 +340,16 @@
     @retval true  Error
 */
 
-bool change_db(Session *session, identifier::Schema &schema_identifier)
+bool change(Session &session, identifier::Schema &schema_identifier)
 {
 
-  if (not plugin::Authorization::isAuthorized(session->user(), schema_identifier))
+  if (not plugin::Authorization::isAuthorized(*session.user(), schema_identifier))
   {
     /* Error message is set in isAuthorized */
     return true;
   }
 
-  if (not check_db_name(session, schema_identifier))
+  if (not check(session, schema_identifier))
   {
     my_error(ER_WRONG_DB_NAME, schema_identifier);
 
@@ -379,7 +381,7 @@
   @param new_db_charset Character set of the new database.
 */
 
-static void change_db_impl(Session *session, identifier::Schema &schema_identifier)
+static void change_db_impl(Session &session, identifier::Schema &schema_identifier)
 {
   /* 1. Change current database in Session. */
 
@@ -402,13 +404,37 @@
       the previous database name, we should do it explicitly.
     */
 
-    session->set_db(schema_identifier.getSchemaName());
-  }
-}
-
-static void change_db_impl(Session *session)
-{
-  session->set_db(string());
-}
+    session.set_db(schema_identifier.getSchemaName());
+  }
+}
+
+static void change_db_impl(Session &session)
+{
+  session.set_db(string());
+}
+
+/*
+  Check if database name is valid
+
+  SYNPOSIS
+    check()
+    org_name		Name of database and length
+
+  RETURN
+    false error
+    true ok
+*/
+
+bool check(Session &session, identifier::Schema &schema_identifier)
+{
+  if (not plugin::Authorization::isAuthorized(*session.user(), schema_identifier))
+  {
+    return false;
+  }
+
+  return schema_identifier.isValid();
+}
+
+} /* namespace schema */
 
 } /* namespace drizzled */

=== renamed file 'drizzled/db.h' => 'drizzled/schema.h'
--- drizzled/db.h	2011-02-09 22:48:12 +0000
+++ drizzled/schema.h	2011-02-15 21:01:34 +0000
@@ -18,8 +18,8 @@
  */
 
 
-#ifndef DRIZZLED_DB_H
-#define DRIZZLED_DB_H
+#ifndef DRIZZLED_SCHEMA_H
+#define DRIZZLED_SCHEMA_H
 
 #include <drizzled/message/schema.h>
 
@@ -29,11 +29,16 @@
 namespace message { class Schema; }
 namespace identifier { class Schema; }
 
-bool create_db(Session *session, const message::Schema &schema_message, const bool is_if_not_exists);
-bool alter_db(Session *session, const message::Schema &schema_message, const message::schema::shared_ptr &original_schema);
-bool rm_db(Session *session, identifier::Schema &identifier, const bool if_exists);
-bool change_db(Session *session, identifier::Schema &identifier);
+namespace schema {
+
+bool create(Session &session, const message::Schema &schema_message, const bool is_if_not_exists);
+bool alter(Session &session, const message::Schema &schema_message, const message::Schema &original_schema);
+bool drop(Session &session, identifier::Schema &identifier, const bool if_exists);
+bool change(Session &session, identifier::Schema &identifier);
+bool check(Session &session, identifier::Schema &schema);
+
+}
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_DB_H */
+#endif /* DRIZZLED_SCHEMA_H */

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-02-14 06:32:03 +0000
+++ drizzled/session.cc	2011-02-15 21:01:34 +0000
@@ -45,7 +45,6 @@
 #include "drizzled/plugin/query_rewrite.h"
 #include "drizzled/probes.h"
 #include "drizzled/table_proto.h"
-#include "drizzled/db.h"
 #include "drizzled/pthread_globals.h"
 #include "drizzled/transaction_services.h"
 #include "drizzled/drizzled.h"
@@ -86,6 +85,8 @@
 
 #include "drizzled/util/backtrace.h"
 
+#include <drizzled/schema.h>
+
 using namespace std;
 
 namespace fs=boost::filesystem;
@@ -598,7 +599,7 @@
 */
 bool Session::isViewable(identifier::User::const_reference user_arg) const
 {
-  return plugin::Authorization::isAuthorized(user_arg, this, false);
+  return plugin::Authorization::isAuthorized(user_arg, *this, false);
 }
 
 
@@ -641,7 +642,7 @@
                         const std::string &in_db)
 {
   bool is_authenticated=
-    plugin::Authentication::isAuthenticated(user(), passwd_str);
+    plugin::Authentication::isAuthenticated(*user(), passwd_str);
 
   if (is_authenticated != true)
   {
@@ -654,7 +655,7 @@
   if (not in_db.empty())
   {
     identifier::Schema identifier(in_db);
-    if (change_db(this, identifier))
+    if (schema::change(*this, identifier))
     {
       /* change_db() has pushed the error message. */
       return false;

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2011-02-10 20:26:46 +0000
+++ drizzled/show.cc	2011-02-15 21:01:34 +0000
@@ -64,11 +64,14 @@
     {
       if (*wildstr == internal::wild_prefix && wildstr[1])
         wildstr++;
+
       if (my_toupper(cs, *wildstr++) != my_toupper(cs, *str++))
         return (1);
     }
+
     if (! *wildstr )
       return (*str != 0);
+
     if (*wildstr++ == internal::wild_one)
     {
       if (! *str++)
@@ -78,6 +81,7 @@
     {						/* Found '*' */
       if (! *wildstr)
         return (0);		/* '*' as last char: OK */
+
       flag=(*wildstr != internal::wild_many && *wildstr != internal::wild_one);
       do
       {
@@ -86,15 +90,21 @@
           char cmp;
           if ((cmp= *wildstr) == internal::wild_prefix && wildstr[1])
             cmp= wildstr[1];
+
           cmp= my_toupper(cs, cmp);
+
           while (*str && my_toupper(cs, *str) != cmp)
             str++;
+
           if (! *str)
             return (1);
         }
+
         if (wild_case_compare(cs, str, wildstr) == 0)
           return (0);
+
       } while (*str++);
+
       return (1);
     }
   }
@@ -183,7 +193,7 @@
     session->getLex()->select_lex.db= const_cast<char *>(ident);
     if (not plugin::StorageEngine::doesSchemaExist(identifier))
     {
-      my_error(ER_BAD_DB_ERROR, MYF(0), ident);
+      my_error(ER_BAD_DB_ERROR, identifier);
     }
     select->setShowPredicate(ident, "");
   }
@@ -256,7 +266,7 @@
     identifier::Schema identifier(ident);
     if (not plugin::StorageEngine::doesSchemaExist(identifier))
     {
-      my_error(ER_BAD_DB_ERROR, MYF(0), ident);
+      my_error(ER_BAD_DB_ERROR, identifier);
     }
 
     select->setShowPredicate(ident, "");

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-02-12 22:27:36 +0000
+++ drizzled/sql_base.cc	2011-02-15 21:01:34 +0000
@@ -1599,7 +1599,7 @@
      * table/schema information via error messages
      */
     identifier::Table the_table(tables->getSchemaName(), tables->getTableName());
-    if (not plugin::Authorization::isAuthorized(user(), the_table))
+    if (not plugin::Authorization::isAuthorized(*user(), the_table))
     {
       result= -1;                               // Fatal error
       break;

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2011-02-09 22:48:12 +0000
+++ drizzled/sql_load.cc	2011-02-15 21:01:34 +0000
@@ -26,7 +26,6 @@
 #include <drizzled/field/epoch.h>
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/iocache.h"
-#include <drizzled/db.h>
 #include "drizzled/plugin/storage_engine.h"
 
 #include <sys/stat.h>

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-02-12 10:06:03 +0000
+++ drizzled/sql_parse.cc	2011-02-15 21:01:34 +0000
@@ -28,7 +28,6 @@
 #include <drizzled/data_home.h>
 #include <drizzled/sql_base.h>
 #include <drizzled/show.h>
-#include <drizzled/db.h>
 #include <drizzled/function/time/unix_timestamp.h>
 #include <drizzled/function/get_system_var.h>
 #include <drizzled/item/cmpfunc.h>
@@ -53,6 +52,8 @@
 #include "drizzled/plugin/event_observer.h"
 #include "drizzled/visibility.h"
 
+#include <drizzled/schema.h>
+
 #include <limits.h>
 
 #include <bitset>
@@ -223,7 +224,7 @@
 
     identifier::Schema identifier(tmp);
 
-    if (not change_db(session, identifier))
+    if (not schema::change(*session, identifier))
     {
       session->my_ok();
     }
@@ -955,7 +956,7 @@
     my_casedn_str(files_charset_info, table->db.str);
 
     identifier::Schema schema_identifier(string(table->db.str));
-    if (not check_db_name(session, schema_identifier))
+    if (not schema::check(*session, schema_identifier))
     {
 
       my_error(ER_WRONG_DB_NAME, MYF(0), table->db.str);

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-02-14 22:31:26 +0000
+++ drizzled/sql_table.cc	2011-02-15 21:01:59 +0000
@@ -27,7 +27,6 @@
 #include <drizzled/session.h>
 #include <drizzled/sql_base.h>
 #include "drizzled/strfunc.h"
-#include <drizzled/db.h>
 #include <drizzled/lock.h>
 #include <drizzled/unireg.h>
 #include <drizzled/item/int.h>
@@ -43,7 +42,6 @@
 
 #include "drizzled/definition/cache.h"
 
-
 #include "drizzled/statement/alter_table.h"
 #include "drizzled/sql_table.h"
 #include "drizzled/pthread_globals.h"
@@ -2002,9 +2000,8 @@
   // a "new" message and it will not have all of the information that the
   // source table message would have.
   message::Table new_table_message;
-  drizzled::error_t error;
 
-  message::table::shared_ptr source_table_message= plugin::StorageEngine::getTableMessage(session, source_identifier, error);
+  message::table::shared_ptr source_table_message= plugin::StorageEngine::getTableMessage(session, source_identifier);
 
   if (not source_table_message)
   {

=== modified file 'drizzled/statement/alter_schema.cc'
--- drizzled/statement/alter_schema.cc	2011-01-22 18:52:16 +0000
+++ drizzled/statement/alter_schema.cc	2011-02-14 17:05:06 +0000
@@ -23,7 +23,7 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/alter_schema.h>
 #include <drizzled/plugin/storage_engine.h>
-#include <drizzled/db.h>
+#include <drizzled/schema.h>
 #include <drizzled/message.h>
 
 #include <string>
@@ -43,7 +43,7 @@
 
   identifier::Schema schema_identifier(string(db->str, db->length));
 
-  if (not check_db_name(getSession(), schema_identifier))
+  if (not schema::check(*getSession(), schema_identifier))
   {
     my_error(ER_WRONG_DB_NAME, schema_identifier);
 
@@ -51,7 +51,7 @@
   }
 
   identifier::Schema identifier(db->str);
-  if (not plugin::StorageEngine::getSchemaDefinition(identifier, old_definition))
+  if (not (old_definition= plugin::StorageEngine::getSchemaDefinition(identifier)))
   {
     my_error(ER_SCHEMA_DOES_NOT_EXIST, identifier); 
     return true;
@@ -83,7 +83,7 @@
   
   drizzled::message::update(schema_message);
 
-  bool res= alter_db(getSession(), schema_message, old_definition);
+  bool res= schema::alter(*getSession(), schema_message, *old_definition);
 
   return not res;
 }

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-02-13 16:50:16 +0000
+++ drizzled/statement/alter_table.cc	2011-02-15 21:01:34 +0000
@@ -119,7 +119,7 @@
   message::table::shared_ptr original_table_message;
   {
     identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
-    if (plugin::StorageEngine::getTableDefinition(*getSession(), identifier, original_table_message) != EEXIST)
+    if (not (original_table_message= plugin::StorageEngine::getTableMessage(*getSession(), identifier)))
     {
       my_error(ER_BAD_TABLE_ERROR, identifier);
       return true;

=== modified file 'drizzled/statement/change_schema.cc'
--- drizzled/statement/change_schema.cc	2011-01-22 07:05:32 +0000
+++ drizzled/statement/change_schema.cc	2011-02-14 17:05:06 +0000
@@ -22,7 +22,7 @@
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/change_schema.h>
-#include <drizzled/db.h>
+#include <drizzled/schema.h>
 
 #include <string>
 
@@ -36,7 +36,7 @@
   Select_Lex *select_lex= &getSession()->lex->select_lex;
 
   identifier::Schema identifier(select_lex->db);
-  if (not change_db(getSession(), identifier))
+  if (not schema::change(*getSession(), identifier))
   {
     getSession()->my_ok();
   }

=== modified file 'drizzled/statement/create_index.cc'
--- drizzled/statement/create_index.cc	2011-02-09 22:48:12 +0000
+++ drizzled/statement/create_index.cc	2011-02-15 21:01:34 +0000
@@ -24,7 +24,6 @@
 #include "drizzled/session.h"
 #include "drizzled/statement/create_index.h"
 #include "drizzled/statement/alter_table.h"
-#include "drizzled/db.h"
 #include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
@@ -51,7 +50,7 @@
   message::table::shared_ptr original_table_message;
   {
     identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
-    if (plugin::StorageEngine::getTableDefinition(*getSession(), identifier, original_table_message) != EEXIST)
+    if (not (original_table_message= plugin::StorageEngine::getTableMessage(*getSession(), identifier)))
     {
       my_error(ER_BAD_TABLE_ERROR, identifier);
       return true;

=== modified file 'drizzled/statement/create_schema.cc'
--- drizzled/statement/create_schema.cc	2011-02-09 22:48:12 +0000
+++ drizzled/statement/create_schema.cc	2011-02-15 21:01:34 +0000
@@ -23,7 +23,7 @@
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/create_schema.h>
-#include <drizzled/db.h>
+#include <drizzled/schema.h>
 #include <drizzled/plugin/event_observer.h>
 #include <drizzled/message.h>
 #include <drizzled/plugin/storage_engine.h>
@@ -62,7 +62,7 @@
   }
   else
   {
-    res= create_db(getSession(), schema_message, getSession()->getLex()->exists());
+    res= schema::create(*getSession(), schema_message, getSession()->getLex()->exists());
     if (unlikely(plugin::EventObserver::afterCreateDatabase(*getSession(), path, res)))
     {
       my_error(ER_EVENT_OBSERVER_PLUGIN, schema_identifier);
@@ -79,7 +79,7 @@
   if (not identifier.isValid())
     return false;
 
-  if (not plugin::Authorization::isAuthorized(getSession()->user(), identifier))
+  if (not plugin::Authorization::isAuthorized(*getSession()->user(), identifier))
     return false;
 
   if (not getSession()->getLex()->exists())

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2011-02-12 10:48:53 +0000
+++ drizzled/statement/create_table.cc	2011-02-15 21:01:34 +0000
@@ -294,7 +294,8 @@
   // See if any storage engine objects to the name of the file
   if (not plugin::StorageEngine::canCreateTable(identifier))
   {
-    my_error(ER_DBACCESS_DENIED_ERROR, MYF(0), "", "", identifier.getSchemaName().c_str());
+    identifier::Schema schema_identifier= identifier;
+    error::access(*getSession()->user(), schema_identifier);
 
     return false;
   }
@@ -303,7 +304,8 @@
   // create for the table.
   if (not plugin::StorageEngine::doesSchemaExist(identifier))
   {
-    my_error(ER_BAD_DB_ERROR, MYF(0), identifier.getSchemaName().c_str());
+    identifier::Schema schema_identifier= identifier;
+    my_error(ER_BAD_DB_ERROR, schema_identifier);
 
     return false;
   }

=== modified file 'drizzled/statement/drop_index.cc'
--- drizzled/statement/drop_index.cc	2011-02-09 22:48:12 +0000
+++ drizzled/statement/drop_index.cc	2011-02-15 21:01:34 +0000
@@ -24,7 +24,6 @@
 #include "drizzled/session.h"
 #include "drizzled/statement/drop_index.h"
 #include "drizzled/statement/alter_table.h"
-#include "drizzled/db.h"
 #include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
@@ -39,7 +38,7 @@
   message::table::shared_ptr original_table_message;
   {
     identifier::Table identifier(first_table->getSchemaName(), first_table->getTableName());
-    if (plugin::StorageEngine::getTableDefinition(*getSession(), identifier, original_table_message) != EEXIST)
+    if (not (original_table_message= plugin::StorageEngine::getTableMessage(*getSession(), identifier)))
     {
       my_error(ER_BAD_TABLE_ERROR, identifier);
       return true;

=== modified file 'drizzled/statement/drop_schema.cc'
--- drizzled/statement/drop_schema.cc	2011-01-22 18:52:16 +0000
+++ drizzled/statement/drop_schema.cc	2011-02-14 17:05:06 +0000
@@ -19,12 +19,14 @@
  */
 
 #include "config.h"
+
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/drop_schema.h>
-#include <drizzled/db.h>
 #include <drizzled/plugin/event_observer.h>
 
+#include <drizzled/schema.h>
+
 #include <string>
 
 using namespace std;
@@ -42,7 +44,7 @@
 
   identifier::Schema schema_identifier(std::string(getSession()->lex->name.str, getSession()->lex->name.length));
 
-  if (not check_db_name(getSession(), schema_identifier))
+  if (not schema::check(*getSession(), schema_identifier))
   {
     my_error(ER_WRONG_DB_NAME, schema_identifier);
 
@@ -66,7 +68,7 @@
   }
   else
   {
-    res= rm_db(getSession(), schema_identifier, drop_if_exists);
+    res= schema::drop(*getSession(), schema_identifier, drop_if_exists);
     if (unlikely(plugin::EventObserver::afterDropDatabase(*getSession(), path, res)))
     {
       my_error(ER_EVENT_OBSERVER_PLUGIN, MYF(0), path.c_str());

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2011-02-09 22:48:12 +0000
+++ drizzled/statement/rename_table.cc	2011-02-15 21:01:34 +0000
@@ -153,22 +153,22 @@
   }
 
   plugin::StorageEngine *engine= NULL;
-  message::table::shared_ptr table_proto;
+  message::table::shared_ptr table_message;
 
   identifier::Table old_identifier(ren_table->getSchemaName(), old_alias, message::Table::STANDARD);
 
-  if (plugin::StorageEngine::getTableDefinition(*getSession(), old_identifier, table_proto) != EEXIST)
+  if (not (table_message= plugin::StorageEngine::getTableMessage(*getSession(), old_identifier)))
   {
     my_error(ER_TABLE_UNKNOWN, old_identifier);
     return true;
   }
 
-  engine= plugin::StorageEngine::findByName(*getSession(), table_proto->engine().name());
+  engine= plugin::StorageEngine::findByName(*getSession(), table_message->engine().name());
 
   identifier::Table new_identifier(new_db, new_alias, message::Table::STANDARD);
   if (plugin::StorageEngine::doesTableExist(*getSession(), new_identifier))
   {
-    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), new_alias);
+    my_error(ER_TABLE_EXISTS_ERROR, new_identifier);
     return 1; // This can't be skipped
   }
 

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2011-02-12 10:06:03 +0000
+++ drizzled/table.cc	2011-02-15 21:01:34 +0000
@@ -323,28 +323,6 @@
 }
 
 /*
-  Check if database name is valid
-
-  SYNPOSIS
-    check_db_name()
-    org_name		Name of database and length
-
-  RETURN
-    false error
-    true ok
-*/
-
-bool check_db_name(Session *session, identifier::Schema &schema_identifier)
-{
-  if (not plugin::Authorization::isAuthorized(session->user(), schema_identifier))
-  {
-    return false;
-  }
-
-  return schema_identifier.isValid();
-}
-
-/*
   Allow anything as a table name, as long as it doesn't contain an
   ' ' at the end
   returns 1 on error

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2011-02-13 16:50:16 +0000
+++ drizzled/table.h	2011-02-15 21:01:34 +0000
@@ -839,7 +839,6 @@
 
 DRIZZLED_API int rename_file_ext(const char * from,const char * to,const char * ext);
 bool check_column_name(const char *name);
-bool check_db_name(Session *session, identifier::Schema &schema);
 bool check_table_name(const char *name, uint32_t length);
 
 } /* namespace drizzled */

=== modified file 'drizzled/transaction_services.cc'
--- drizzled/transaction_services.cc	2011-02-14 06:32:03 +0000
+++ drizzled/transaction_services.cc	2011-02-15 21:01:34 +0000
@@ -1987,7 +1987,7 @@
 }
 
 void TransactionServices::alterSchema(Session::reference session,
-                                      const message::schema::shared_ptr &old_schema,
+                                      const message::Schema &old_schema,
                                       const message::Schema &new_schema)
 {
   ReplicationServices &replication_services= ReplicationServices::singleton();
@@ -2008,7 +2008,7 @@
   message::Schema *before= alter_schema_statement->mutable_before();
   message::Schema *after= alter_schema_statement->mutable_after();
 
-  *before= *old_schema;
+  *before= old_schema;
   *after= new_schema;
 
   finalizeStatementMessage(*statement, session);

=== modified file 'drizzled/transaction_services.h'
--- drizzled/transaction_services.h	2011-02-12 05:57:44 +0000
+++ drizzled/transaction_services.h	2011-02-15 21:01:34 +0000
@@ -155,7 +155,7 @@
    * @param[in] new_schema New schema definition
    */
   void alterSchema(Session::reference session,
-                   const message::schema::shared_ptr &old_schema,
+                   const message::Schema &old_schema,
                    const message::Schema &new_schema);
 
   /**

=== modified file 'plugin/auth_file/tests/r/basic.result'
--- plugin/auth_file/tests/r/basic.result	2010-06-19 15:32:47 +0000
+++ plugin/auth_file/tests/r/basic.result	2011-02-16 00:52:49 +0000
@@ -1,5 +1,5 @@
 connect(localhost,bad_user,,test,MASTER_PORT,);
-ERROR 28000: Access denied for user 'bad_user'@'LOCALHOST' (using password: NO)
+ERROR 28000: Access denied for user 'bad_user' (using password: NO)
 SELECT 1;
 1
 1
@@ -7,6 +7,6 @@
 1
 1
 connect(localhost,auth_file_password,bad_password,test,MASTER_PORT,);
-ERROR 28000: Access denied for user 'auth_file_password'@'LOCALHOST' (using password: YES)
+ERROR 28000: Access denied for user 'auth_file_password' (using password: YES)
 1
 1

=== modified file 'plugin/auth_test/tests/r/basic.result'
--- plugin/auth_test/tests/r/basic.result	2010-03-18 18:09:04 +0000
+++ plugin/auth_test/tests/r/basic.result	2011-02-16 00:52:49 +0000
@@ -1,19 +1,19 @@
 connect(localhost,,,test,MASTER_PORT,);
-ERROR 28000: Access denied for user ''@'LOCALHOST' (using password: NO)
+ERROR 28000: Access denied for user '<no user>' (using password: NO)
 connect(localhost,password_ok,,test,MASTER_PORT,);
-ERROR 28000: Access denied for user 'password_ok'@'LOCALHOST' (using password: NO)
+ERROR 28000: Access denied for user 'password_ok' (using password: NO)
 SELECT 1;
 1
 1
 connect(localhost,no_password_ok,test,test,MASTER_PORT,);
-ERROR 28000: Access denied for user 'no_password_ok'@'LOCALHOST' (using password: YES)
+ERROR 28000: Access denied for user 'no_password_ok' (using password: YES)
 SELECT 1;
 1
 1
 connect(localhost,scramble_ok,,test,MASTER_PORT,);
-ERROR 28000: Access denied for user 'scramble_ok'@'LOCALHOST' (using password: NO)
+ERROR 28000: Access denied for user 'scramble_ok' (using password: NO)
 connect(localhost,scramble_ok,bad_scramble,test,MASTER_PORT,);
-ERROR 28000: Access denied for user 'scramble_ok'@'LOCALHOST' (using password: YES)
+ERROR 28000: Access denied for user 'scramble_ok' (using password: YES)
 SELECT 1;
 1
 1

=== modified file 'plugin/function_engine/function.cc'
--- plugin/function_engine/function.cc	2011-01-29 23:08:49 +0000
+++ plugin/function_engine/function.cc	2011-02-13 00:42:54 +0000
@@ -73,9 +73,9 @@
   schemas.push_back(DATA_DICTIONARY_IDENTIFIER);
 }
 
-bool Function::doGetSchemaDefinition(const identifier::Schema &schema_identifier, message::schema::shared_ptr &schema_message)
+drizzled::message::schema::shared_ptr Function::doGetSchemaDefinition(const identifier::Schema &schema_identifier)
 {
-  schema_message.reset(new message::Schema); // This should be fixed, we could just be using ones we built on startup.
+  drizzled::message::schema::shared_ptr schema_message;
 
   if (schema_identifier == INFORMATION_SCHEMA_IDENTIFIER)
   {
@@ -87,10 +87,10 @@
   }
   else
   {
-    return false;
+    return drizzled::message::schema::shared_ptr();
   }
 
-  return true;
+  return schema_message;
 }
 
 bool Function::doCanCreateTable(const drizzled::identifier::Table &table_identifier)

=== modified file 'plugin/function_engine/function.h'
--- plugin/function_engine/function.h	2011-01-17 04:15:23 +0000
+++ plugin/function_engine/function.h	2011-02-13 00:42:54 +0000
@@ -82,7 +82,7 @@
 
   bool doDoesTableExist(drizzled::Session& session, const drizzled::identifier::Table &identifier);
 
-  bool doGetSchemaDefinition(const drizzled::identifier::Schema &schema, drizzled::message::schema::shared_ptr &schema_message);
+  drizzled::message::schema::shared_ptr doGetSchemaDefinition(const drizzled::identifier::Schema &schema);
 
   int doRenameTable(drizzled::Session&, const drizzled::identifier::Table &, const drizzled::identifier::Table &)
   {

=== modified file 'plugin/schema_engine/schema.cc'
--- plugin/schema_engine/schema.cc	2011-01-25 01:06:40 +0000
+++ plugin/schema_engine/schema.cc	2011-02-14 02:47:12 +0000
@@ -21,7 +21,7 @@
 #include "config.h"
 
 #include "plugin/schema_engine/schema.h"
-#include "drizzled/db.h"
+#include "drizzled/schema.h"
 #include "drizzled/sql_table.h"
 #include "drizzled/global_charset_info.h"
 #include "drizzled/charset.h"
@@ -116,21 +116,22 @@
   mutex.unlock_shared();
 }
 
-bool Schema::doGetSchemaDefinition(const identifier::Schema &schema_identifier, message::schema::shared_ptr &schema_message)
+drizzled::message::schema::shared_ptr Schema::doGetSchemaDefinition(const identifier::Schema &schema_identifier)
 {
   mutex.lock_shared();
   SchemaCache::iterator iter= schema_cache.find(schema_identifier.getPath());
 
   if (iter != schema_cache.end())
   {
+    drizzled::message::schema::shared_ptr schema_message;
     schema_message= (*iter).second;
     mutex.unlock_shared();
 
-    return true;
+    return schema_message;
   }
   mutex.unlock_shared();
 
-  return false;
+  return drizzled::message::schema::shared_ptr();
 }
 
 
@@ -168,13 +169,11 @@
 
 bool Schema::doDropSchema(const identifier::Schema &schema_identifier)
 {
-  message::schema::shared_ptr schema_message;
-
   string schema_file(schema_identifier.getPath());
   schema_file.append(1, FN_LIBCHAR);
   schema_file.append(MY_DB_OPT_FILE);
 
-  if (not doGetSchemaDefinition(schema_identifier, schema_message))
+  if (not doGetSchemaDefinition(schema_identifier))
     return false;
 
   // No db.opt file, no love from us.

=== modified file 'plugin/schema_engine/schema.h'
--- plugin/schema_engine/schema.h	2011-01-25 01:06:40 +0000
+++ plugin/schema_engine/schema.h	2011-02-13 00:42:54 +0000
@@ -59,7 +59,7 @@
   }
 
   void doGetSchemaIdentifiers(drizzled::identifier::Schema::vector &set_of_names);
-  bool doGetSchemaDefinition(const drizzled::identifier::Schema&, drizzled::message::schema::shared_ptr &proto);
+  drizzled::message::schema::shared_ptr doGetSchemaDefinition(const drizzled::identifier::Schema&);
 
   bool doCreateSchema(const drizzled::message::Schema &schema_message);
 

=== modified file 'plugin/show_dictionary/show_columns.cc'
--- plugin/show_dictionary/show_columns.cc	2011-01-17 04:15:23 +0000
+++ plugin/show_dictionary/show_columns.cc	2011-02-13 05:14:35 +0000
@@ -67,9 +67,10 @@
     table_name.append(select->getShowTable().c_str());
     identifier::Table identifier(select->getShowSchema().c_str(), select->getShowTable().c_str());
 
-    is_tables_primed= plugin::StorageEngine::getTableDefinition(getSession(),
-                                                                identifier,
-                                                                table_proto);
+    table_proto= plugin::StorageEngine::getTableMessage(getSession(), identifier);
+
+    if (table_proto)
+      is_tables_primed= true;
   }
 }
 

=== modified file 'plugin/show_dictionary/show_create_schema.cc'
--- plugin/show_dictionary/show_create_schema.cc	2011-01-16 19:48:25 +0000
+++ plugin/show_dictionary/show_create_schema.cc	2011-02-12 10:35:45 +0000
@@ -37,7 +37,6 @@
 
 ShowCreateSchema::Generator::Generator(Field **arg) :
   show_dictionary::Show::Generator(arg),
-  is_primed(false),
   if_not_exists(false)
 {
   if (not isShowQuery())
@@ -50,8 +49,7 @@
     schema_name.append(select->getShowTable());
     identifier::Schema identifier(select->getShowSchema());
 
-    is_primed= plugin::StorageEngine::getSchemaDefinition(identifier,
-                                                          schema_message);
+    schema_message= plugin::StorageEngine::getSchemaDefinition(identifier);
 
     if_not_exists= select->getShowExists();
   }
@@ -59,7 +57,7 @@
 
 bool ShowCreateSchema::Generator::populate()
 {
-  if (not is_primed)
+  if (not schema_message)
     return false;
 
   std::string buffer;
@@ -84,7 +82,8 @@
 
   push(schema_message->name());
   push(buffer);
-  is_primed= false;
+
+  schema_message.reset();
 
   return true;
 }

=== modified file 'plugin/show_dictionary/show_create_schema.h'
--- plugin/show_dictionary/show_create_schema.h	2010-12-01 20:06:11 +0000
+++ plugin/show_dictionary/show_create_schema.h	2011-02-12 10:35:45 +0000
@@ -30,7 +30,6 @@
 
   class Generator : public show_dictionary::Show::Generator 
   {
-    bool is_primed;
     bool if_not_exists;
     std::string schema_name;
     drizzled::message::schema::shared_ptr schema_message;

=== modified file 'plugin/show_dictionary/show_create_table.cc'
--- plugin/show_dictionary/show_create_table.cc	2011-01-17 04:15:23 +0000
+++ plugin/show_dictionary/show_create_table.cc	2011-02-13 05:14:35 +0000
@@ -49,11 +49,9 @@
   {
     identifier::Table identifier(select->getShowSchema(), select->getShowTable());
 
-    int error= plugin::StorageEngine::getTableDefinition(getSession(),
-                                                         identifier,
-                                                         table_message);
+    table_message= plugin::StorageEngine::getTableMessage(getSession(), identifier);
 
-    if (error == EEXIST)
+    if (table_message)
       is_primed= true;
   }
 }

=== modified file 'plugin/show_dictionary/show_indexes.cc'
--- plugin/show_dictionary/show_indexes.cc	2011-01-17 04:15:23 +0000
+++ plugin/show_dictionary/show_indexes.cc	2011-02-13 05:14:35 +0000
@@ -54,9 +54,10 @@
     table_name.append(select->getShowTable().c_str());
     identifier::Table identifier(select->getShowSchema().c_str(), select->getShowTable().c_str());
 
-    is_tables_primed= plugin::StorageEngine::getTableDefinition(getSession(),
-                                                                identifier,
-                                                                table_proto);
+    table_proto= plugin::StorageEngine::getTableMessage(getSession(), identifier);
+
+    if (table_proto)
+      is_tables_primed= true;
   }
 }
 

=== modified file 'plugin/show_schema_proto/show_schema_proto.cc'
--- plugin/show_schema_proto/show_schema_proto.cc	2011-02-09 22:48:12 +0000
+++ plugin/show_schema_proto/show_schema_proto.cc	2011-02-15 21:01:34 +0000
@@ -17,8 +17,6 @@
 #include "config.h"
 
 #include <drizzled/charset.h>
-#include <drizzled/current_session.h>
-#include <drizzled/db.h>
 #include <drizzled/error.h>
 #include <drizzled/function/str/strfunc.h>
 #include <drizzled/internal/my_sys.h>
@@ -86,9 +84,9 @@
 
 
   identifier::Schema schema_identifier(db);
-  if (not plugin::StorageEngine::getSchemaDefinition(schema_identifier, proto))
+  if (not (proto= plugin::StorageEngine::getSchemaDefinition(schema_identifier)))
   {
-    my_error(ER_BAD_DB_ERROR, MYF(0), db);
+    my_error(ER_BAD_DB_ERROR, schema_identifier);
     return NULL;
   }
 

=== modified file 'plugin/simple_user_policy/tests/r/basic.result'
--- plugin/simple_user_policy/tests/r/basic.result	2011-02-04 08:47:29 +0000
+++ plugin/simple_user_policy/tests/r/basic.result	2011-02-16 00:52:49 +0000
@@ -19,11 +19,11 @@
 INFORMATION_SCHEMA
 user1
 SELECT * from user2.dont_exist;
-ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to schema 'user2'
+ERROR 42000: Access denied for user 'user1' to schema 'user2'
 create schema authorize_fail;
-ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to schema 'authorize_fail'
+ERROR 42000: Access denied for user 'user1' to schema 'authorize_fail'
 drop schema user2;
-ERROR 42000: Access denied for user 'user1'@'LOCALHOST' to schema 'user2'
+ERROR 42000: Access denied for user 'user1' to schema 'user2'
 create table t1 (kill_id int);
 insert into t1 values(connection_id());
 SELECT USERNAME, DB FROM DATA_DICTIONARY.PROCESSLIST ORDER BY USERNAME, DB;
@@ -67,6 +67,6 @@
 @id != connection_id()
 1
 connect(localhost,authz,,authz_no,MASTER_PORT,);
-ERROR 42000: Access denied for user 'authz'@'LOCALHOST' to schema 'authz_no'
+ERROR 42000: Access denied for user 'authz' to schema 'authz_no'
 drop schema user1;
 drop schema user2;

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2011-02-02 00:12:03 +0000
+++ po/POTFILES.in	2011-02-14 17:05:06 +0000
@@ -7,7 +7,6 @@
 client/drizzleslap.cc
 client/drizzletest.cc
 drizzled/cursor.cc
-drizzled/db.cc
 drizzled/drizzled.cc
 drizzled/error.cc
 drizzled/gettext.h
@@ -41,6 +40,7 @@
 drizzled/plugin/xa_resource_manager.cc
 drizzled/plugin/xa_storage_engine.cc
 drizzled/replication_services.cc
+drizzled/schema.cc
 drizzled/session.cc
 drizzled/set_var.cc
 drizzled/show.cc

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2011-01-26 06:50:16 +0000
+++ tests/r/data_dictionary_like_info.result	2011-02-16 00:52:49 +0000
@@ -153,7 +153,7 @@
 use data_dictionary;
 use data_dictionary;
 create temporary table schemas(f1 char(10));
-ERROR 42000: Access denied for user ''@'' to schema 'data_dictionary'
+ERROR 42000: Access denied for user 'root' to schema 'data_dictionary'
 use test;
 create table t1(id int);
 insert into t1(id) values (1);

